aboutsummaryrefslogtreecommitdiffstats
path: root/cmd
diff options
context:
space:
mode:
authorPéter Szilágyi <peterke@gmail.com>2016-06-29 16:44:40 +0800
committerPéter Szilágyi <peterke@gmail.com>2016-06-29 16:44:40 +0800
commitd55fc35df1ca4996048625421d4c475a437d273e (patch)
tree524f041d216fc9023fc0cfeaefd81631e13a1f35 /cmd
parent67e9d3348679d87cca127de4da8eb4223c43aae2 (diff)
downloadgo-tangerine-d55fc35df1ca4996048625421d4c475a437d273e.tar
go-tangerine-d55fc35df1ca4996048625421d4c475a437d273e.tar.gz
go-tangerine-d55fc35df1ca4996048625421d4c475a437d273e.tar.bz2
go-tangerine-d55fc35df1ca4996048625421d4c475a437d273e.tar.lz
go-tangerine-d55fc35df1ca4996048625421d4c475a437d273e.tar.xz
go-tangerine-d55fc35df1ca4996048625421d4c475a437d273e.tar.zst
go-tangerine-d55fc35df1ca4996048625421d4c475a437d273e.zip
Revert "core: add voting and result tracking for the dao soft-fork"
This reverts commit c4de28938ff8c688c4444c8b3e8e28a52cbc62ff.
Diffstat (limited to 'cmd')
-rw-r--r--cmd/utils/flags.go14
1 files changed, 7 insertions, 7 deletions
diff --git a/cmd/utils/flags.go b/cmd/utils/flags.go
index c732a6635..802e54c73 100644
--- a/cmd/utils/flags.go
+++ b/cmd/utils/flags.go
@@ -163,8 +163,8 @@ var (
}
// Miner settings
// TODO: refactor CPU vs GPU mining flags
- BlockedCodeHashesFlag = cli.StringFlag{
- Name: "blocked-code-hashes",
+ IllegalCodeHashesFlag = cli.StringFlag{
+ Name: "illegal-code-hashes",
Usage: "Comma separated list of code-hashes to ignore any interaction from",
}
MiningEnabledFlag = cli.BoolFlag{
@@ -644,9 +644,9 @@ func MakePasswordList(ctx *cli.Context) []string {
return lines
}
-// MakeBlockedCodeHashes parses a comma separated list of hashes.
-func MakeBlockedCodeHashes(ctx *cli.Context) map[common.Hash]struct{} {
- splittedHexHashes := strings.Split(ctx.GlobalString(BlockedCodeHashesFlag.Name), ",")
+// ParseIllegalCodeHashes parses a comma separated list of hashes.
+func ParseIllegalCodeHashes(ctx *cli.Context) map[common.Hash]struct{} {
+ splittedHexHashes := strings.Split(ctx.GlobalString(IllegalCodeHashesFlag.Name), ",")
illegalCodeHashes := make(map[common.Hash]struct{})
for _, hexHash := range splittedHexHashes {
illegalCodeHashes[common.HexToHash(strings.TrimSpace(hexHash))] = struct{}{}
@@ -690,8 +690,8 @@ func MakeSystemNode(name, version string, relconf release.Config, extra []byte,
}
// Configure the Ethereum service
accman := MakeAccountManager(ctx)
- // parse the blocked code hashes and set them to the core package.
- core.BlockedCodeHashes = MakeBlockedCodeHashes(ctx)
+ // parse the illegal code hashes and set them to the core package.
+ core.IllegalCodeHashes = ParseIllegalCodeHashes(ctx)
// initialise new random number generator
rand := rand.New(rand.NewSource(time.Now().UnixNano()))